import json
import traceback

from flask import request, jsonify
from flask_restx import Resource, Namespace, reqparse

from app.defines import StatesCode
from application import Application
from starearth.utils.general_utils import print_log

ns = Namespace('mission', description='任务管理 API接口')

slice_mission_parser = reqparse.RequestParser(bundle_errors=True)
slice_mission_parser.add_argument(name='data_path', type=str, location='from', required=False,help='数据目录')
slice_mission_parser.add_argument(name='tile_size', type=int, location='from', required=False,help='瓦片大小')
slice_mission_parser.add_argument(name='tile_format', type=int, location='from', required=False,help='瓦片格式：png、jpeg、tif')
slice_mission_parser.add_argument(name='auto_zoom', type=int, location='from', required=False,help='是否自动切片,0:否，1:是')
slice_mission_parser.add_argument(name='min_zoom', type=int, location='from', required=False,help='最小切片层级')
slice_mission_parser.add_argument(name='max_zoom', type=int, location='from', required=False,help='最大切片层级')



@ns.route('/mission_slice_api')
class MissionAPI(Resource):

    @ns.doc(id='slice', description='切片')
    @ns.expect(slice_mission_parser)
    def post(self):
        """添加任务"""
        try:
            form = request.form
            data_path = form.get('data_path')
            tile_size = form.get('tile_size')
            tile_grid = form.get('tile_grid')
            tile_format = form.get('tile_format')
            auto_zoom = form.get('auto_zoom')
            min_zoom = form.get('min_zoom')
            max_zoom = form.get('max_zoom')

            application = Application()
            application.new_mission(
                data_path=data_path,
                tile_size=tile_size,
                tile_grid=tile_grid,
                tile_format=tile_format,
                auto_zoom=auto_zoom,
                min_zoom=min_zoom,
                max_zoom=max_zoom

            )

            # 添加至dem
            # try:
            #     key_status_upload(proxy_host=config.common.RPOXY_SERVICE_HOST,       # 上报服务的IP
            #                       proxy_port=str(config.common.RPOXY_SERVICE_PORT),  # 上报服务的端口
            #                       software_key=root_mission_id,                      # 任务标识
            #                       software_name=mission_name,                        # 任务名称
            #                       software_status='0',                               # 字符串类型的数字
            #                       software_warn_desc='任务创建成功',                   # 描述
            #                       is_enable=config.common.ENABLE_PROXY_BASE)         # 是否上报
            # except Exception as err:
            #     print_log('任务上报失败')

            return {"code": StatesCode.SUCCESS, "message": "任务添加成功"}

        except Exception as err:

            traceback.print_exc()

            return {"code": StatesCode.UNKNOWN_ERROR, "message": str(err)}
